.. _linux.ubuntu_mc:

##################
linux.ubuntu
##################

This Model Component provides an UbuntuHost object that has functionality common to all versions of Ubuntu.
This notably includes a function to install debian packages.

**Model Component Dependencies:**
    * :ref:`linux.base_objects_mc`

*****************
Available Objects
*****************

.. automodule:: linux.ubuntu
    :members:
    :undoc-members:
    :special-members:
    :private-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__,__module__
